@@ -1,20 +1,18 @@
 """
     Url router for the user dashboard
 """
+
 from django.contrib.auth.decorators import login_required
 from django.urls import re_path
 from django.urls import reverse_lazy
 
+from core_dashboard_app.views.common import views as dashboard_app_common_views
 from core_dashboard_common_app.views.common import (
     ajax,
     views as dashboard_common_app_common_views,
 )
-from core_dashboard_common_app.views.common.views import (
-    UserDashboardPasswordChangeFormView,
-)
 from core_main_app.settings import INSTALLED_APPS
 from core_main_app.views.common.ajax import EditTemplateVersionManagerView
-from core_dashboard_app.views.common import views as dashboard_app_common_views
 
 urlpatterns = [
     # Common
@@ -33,14 +31,6 @@ urlpatterns = [
         dashboard_common_app_common_views.my_profile_edit,
         name="core_dashboard_profile_edit",
     ),
-    re_path(
-        r"^my-profile/change-password",
-        UserDashboardPasswordChangeFormView.as_view(
-            template_name="core_dashboard_common_app/my_profile_change_password.html",
-            success_url="/",
-        ),
-        name="core_dashboard_profile_change_password",
-    ),
     re_path(
         r"^delete-document",
         ajax.delete_document,
@@ -59,7 +49,6 @@ urlpatterns = [
         r"^records$",
         login_required(
             dashboard_common_app_common_views.DashboardRecords.as_view(),
-            login_url=reverse_lazy("core_main_app_login"),
         ),
         name="core_dashboard_records",
     ),
@@ -67,7 +56,6 @@ urlpatterns = [
         r"^forms$",
         login_required(
             dashboard_common_app_common_views.DashboardForms.as_view(),
-            login_url=reverse_lazy("core_main_app_login"),
         ),
         name="core_dashboard_forms",
     ),
@@ -75,7 +63,6 @@ urlpatterns = [
         r"^templates$",
         login_required(
             dashboard_common_app_common_views.DashboardTemplates.as_view(),
-            login_url=reverse_lazy("core_main_app_login"),
         ),
         name="core_dashboard_templates",
     ),
@@ -83,7 +70,6 @@ urlpatterns = [
         r"^types$",
         login_required(
             dashboard_common_app_common_views.DashboardTypes.as_view(),
-            login_url=reverse_lazy("core_main_app_login"),
         ),
         name="core_dashboard_types",
     ),
@@ -91,7 +77,6 @@ urlpatterns = [
         r"^files$",
         login_required(
             dashboard_common_app_common_views.DashboardFiles.as_view(),
-            login_url=reverse_lazy("core_main_app_login"),
         ),
         name="core_dashboard_files",
     ),
@@ -99,7 +84,6 @@ urlpatterns = [
         r"^queries$",
         login_required(
             dashboard_common_app_common_views.DashboardQueries.as_view(),
-            login_url=reverse_lazy("core_main_app_login"),
         ),
         name="core_dashboard_queries",
     ),
@@ -107,7 +91,6 @@ urlpatterns = [
         r"^workspaces$",
         login_required(
             dashboard_common_app_common_views.DashboardWorkspaces.as_view(),
-            login_url=reverse_lazy("core_main_app_login"),
         ),
         name="core_dashboard_workspaces",
     ),
@@ -115,7 +98,6 @@ urlpatterns = [
         r"^workspace/(?P<workspace_id>\w+)$",
         login_required(
             dashboard_app_common_views.DashboardWorkspaceTabs.as_view(),
-            login_url=reverse_lazy("core_main_app_login"),
         ),
         name="core_dashboard_workspace_list",
     ),
