@@ -1,3 +1,6 @@
+""" Conf urls
+"""
+
 from django.conf.urls import include
 from django.contrib import admin
 from django.urls import re_path
